pub enum ColorKind {
LinearGradient(LinearGradient),
RadialGradient(RadialGradient),
ConicalGradient(ConicalGradient),
SolidColor(SolidColor),
}Expand description
An enum to describe the possible kinds of colors used when rendering various
Layer attributes/properties.
Variants
LinearGradient(LinearGradient)
A kind of LinearGradient.
RadialGradient(RadialGradient)
A kind of RadialGradient.
ConicalGradient(ConicalGradient)
A kind of ConicalGradient.
SolidColor(SolidColor)
A kind of SolidColor.
Implementations
Sourceimpl ColorKind
impl ColorKind
Sourcepub fn get_color_tuple_at(&self, x: u32, y: u32) -> (u8, u8, u8, u8)
pub fn get_color_tuple_at(&self, x: u32, y: u32) -> (u8, u8, u8, u8)
Returns the resolved RGBA tuple for the color at the given pixel coordinates.
Sourcepub fn is_transparent(&self) -> bool
pub fn is_transparent(&self) -> bool
Returns true if self is a SolidColor and fully transparent.