pub enum Spread {
Pad,
Reflect,
Repeat,
}Expand description
A enumeration to describe gradient spread behavior at the bounds of the gradient.
This only applies to LinearGradient and RadialGradient, not ConicalGradient.
Variants
Pad
Extends the edge colors beyond the gradient bounds.
Reflect
Mirrors the gradient repeatedly beyond the gradient bounds.
Repeat
Restarts the gradient from the beginning beyond the gradient bounds.