pub enum TypographyAlign {
StartTop,
StartCenter,
StartBottom,
CenterTop,
Center,
CenterCenter,
CenterBottom,
EndTop,
EndCenter,
EndBottom,
}Expand description
A enumeration of the possible alignment options for the text in a Typography attribute.
Variants
StartTop
Aligns text to the top-left corner.
StartCenter
Aligns text to the vertical center of the left edge.
StartBottom
Aligns text to the bottom-left corner.
CenterTop
Aligns text to the horizontal center of the top edge.
Center
Centers text horizontally and vertically.
CenterCenter
Centers text horizontally and vertically.
CenterBottom
Aligns text to the horizontal center of the bottom edge.
EndTop
Aligns text to the top-right corner.
EndCenter
Aligns text to the vertical center of the right edge.
EndBottom
Aligns text to the bottom-right corner.