pub struct Background {
pub image: Option<String>,
pub color: Option<ColorKind>,
pub preserve_aspect: PreserveAspect,
}Expand description
An attribute to describe a Layer’s
background.
Fields
image: Option<String>A path to an image file.
If the given image path has no file extension, then it will be treated as an SVG image.
This also supports built-in SVG icons from the following icon packs:
- Material Design Icons (
material/{icon_slug}) - Simple Icons (
simple/{icon_slug}) - Octicons (
octicons/{icon_slug}) - FontAwesome Free (
fontawesome/<brands|solid|regular>/{icon_slug})
Otherwise, the image file’s path is resolved via a search through the list of
external_resource_paths provided to the Generator (in img_gen_renderer crate),
which defaults to the current working directory if unspecified or an empty list.
color: Option<ColorKind>A color overlaid on top of the image.
If no image is specified, then the layer is simple filled with this color.
preserve_aspect: PreserveAspectThis controls how the original image is rendered into the layer. Default is to preserve the original image’s width and height.