pub struct Debug {
pub enable: bool,
pub grid: bool,
pub grid_step: u32,
pub color: SolidColor,
}Expand description
A struct to describe a Layout’s visual debug output.
Fields
enable: boolA flag to enable or disable the debug output.
grid: boolA flag to control if the debug output shall show a grid of points over the layout.
grid_step: u32The space between points on the debug output’s grid.
color: SolidColorThe color used to outline debug output.
Implementations
Sourceimpl Debug
impl Debug
Sourcepub fn get_foreground_color(&self) -> SolidColor
pub fn get_foreground_color(&self) -> SolidColor
Calculate a black or white foreground color using Debug::color as a background.