pub struct Image {
pub data: ImageBuffer<Rgba<u8>, Vec<u8>>,
}Expand description
A class to represent an Image object.
This class cannot be constructed from python, rather it is returned from
Generator.render()
Fields
data: ImageBuffer<Rgba<u8>, Vec<u8>>The raw RGBA pixel buffer for the rendered image.
Implementations
Sourceimpl Image
impl Image
Sourcepub fn save<P>(&self, name: P) -> Result<(), ImgGenRendererError>
pub fn save<P>(&self, name: P) -> Result<(), ImgGenRendererError>
Save the image to a file.
Does not support SVG output.
The file format is inferred from the file extension in the given name.
Sourcepub fn get_bytes(&self) -> Result<Cow<'_, [u8]>, ImgGenRendererError>
pub fn get_bytes(&self) -> Result<Cow<'_, [u8]>, ImgGenRendererError>
Get a byte array of the image data.
Sourcepub fn get_sha256(&self) -> Result<String, ImgGenRendererError>
pub fn get_sha256(&self) -> Result<String, ImgGenRendererError>
Get the SHA256 hash of the image data as a hex string.