pub struct Line {
pub amount: NonZero<i32>,
pub height: LineHeight,
}Expand description
A property to implicitly describe the size of the text in a
Typography attribute.
Fields
amount: NonZero<i32>The maximum number of lines in the layer.
This value shall not be less than or equal to zero.
height: LineHeightThe height ratio of each line in the layer.
This value shall not be less than or equal to zero.
Implementations