pub struct LineHeight(/* private fields */);Expand description
A custom type to ensure the minimum number of lines is a positive, non-zero f32.
Implementations
Sourceimpl LineHeight
impl LineHeight
Sourcepub fn new(height: f32) -> Option<LineHeight>
pub fn new(height: f32) -> Option<LineHeight>
Creates a line-height ratio where height is not equal to zero.
Sourcepub fn deserialize<'de, D>(
deserializer: D,
) -> Result<LineHeight, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
pub fn deserialize<'de, D>(
deserializer: D,
) -> Result<LineHeight, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserializes a non-zero line-height ratio.