pub struct Polygon {
pub border: Option<Border>,
pub color: ColorKind,
pub sides: PolygonSides,
pub rotation: f32,
}Expand description
An attribute to represent a Polygon rendered in the layer.
Fields
border: Option<Border>The Border (if specified) ro render around the polygon.
color: ColorKindThe color used to fill the polygon.
sides: PolygonSidesThe polygon side definition.
Regular polygons use a side count, while irregular polygons use explicit vertex offsets.
rotation: f32The rotation applied to the rendered polygon.
Does not affect PolygonSides::Irregular.