pub struct RadialGradient {
pub spread: Spread,
/* private fields */
}Expand description
A data structure to represent a radial gradient.
Fields
spread: SpreadThe gradient Spread
Implementations
Sourceimpl RadialGradient
impl RadialGradient
Sourcepub fn new(
colors: ColorGradient,
center: LayerOffset,
radius: f32,
focal_point: Option<LayerOffset>,
focal_radius: Option<f32>,
spread: Option<Spread>,
) -> RadialGradient
pub fn new( colors: ColorGradient, center: LayerOffset, radius: f32, focal_point: Option<LayerOffset>, focal_radius: Option<f32>, spread: Option<Spread>, ) -> RadialGradient
Creates a radial gradient from colors, center, radius, and
optional focal settings.
Focal values are clamped to remain within the outer gradient circle.
Sourcepub fn get_center(&self) -> LayerOffset
pub fn get_center(&self) -> LayerOffset
The center (Offset) of the gradient (relative to the Layer.offset).
Sourcepub fn set_center(&mut self, val: LayerOffset)
pub fn set_center(&mut self, val: LayerOffset)
Sets the gradient center.
Updating the center resets the focal point and focal radius to the new origin.
Sourcepub fn get_radius(&self) -> f32
pub fn get_radius(&self) -> f32
The radius of the gradient.
Sourcepub fn set_radius(&mut self, val: f32)
pub fn set_radius(&mut self, val: f32)
Sets the gradient radius.
Sourcepub fn get_focal_point(&self) -> LayerOffset
pub fn get_focal_point(&self) -> LayerOffset
The focal point (Offset) of the gradient (relative to the Layer.offset).
Sourcepub fn set_focal_point(&mut self, val: LayerOffset)
pub fn set_focal_point(&mut self, val: LayerOffset)
Sets the focal point used to bias the radial gradient.
Sourcepub fn get_focal_radius(&self) -> f32
pub fn get_focal_radius(&self) -> f32
Returns the focal radius.
Sourcepub fn set_focal_radius(&mut self, val: f32)
pub fn set_focal_radius(&mut self, val: f32)
Sets the focal radius.
The value is clamped to remain within the outer gradient circle.
Sourcepub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
pub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
A helper function for renderers to get the color at a certain point.
The given x and y values are the coordinate of the pixel in the Layer
(relative to Layer::offset).