pub struct Typography {
pub content: String,
pub align: TypographyAlign,
pub color: ColorKind,
pub line: Line,
pub overflow: bool,
pub font: Font,
pub border: Option<Border>,
}Expand description
An attribute to represent a Layer’s rendered text.
Fields
content: StringThe text content.
align: TypographyAlignThe alignment of the text.
color: ColorKindThe color used to fill the rendered text.
line: LineThe Line property used to describe the text’s size.
overflow: boolControls how text that doesn’t fit within the layer’s bounds is handled.
true: the font size is progressively reduced until all text fits within the layer.false: text wraps within the layer’s horizontal boundary; any text that still overflows is replaced with a trailing ellipsis (…).
font: FontThe Font property used to describe the font used to render the text.
border: Option<Border>The border (if specified) to draw around the rendered glyphs of the content.