pub struct Layout {
pub size: Size,
pub layers: Vec<Layer>,
pub debug: Option<Debug>,
}Expand description
A data structure used to represent a generated image’s layout.
Fields
size: SizeThe layout’s Size
layers: Vec<Layer>A list of the layout’s Layer objects.
debug: Option<Debug>An optional Debug attribute can be used to show the constraints of the Layout’s layers.